library(tidyverse)

# Clean data and change allele calls to minor allele counts
dat <- read_csv("../data/AlleleCounts/fullPCRData.csv", na = c("U")) %>%
  mutate(across(c(breed, sex, status), as.factor)) %>%
  mutate(dob = as.Date(dob, format = "%m/%d/%Y")) %>% 
  # BICF2S23230472 (CFA 14) is A/C with A minor
  mutate(BICF2S23230472 = case_when(
    BICF2S23230472 == "C C" ~ 0,
    BICF2S23230472 == "A C" ~ 1,
    BICF2S23230472 == "A A" ~ 2,
  )) %>% 
  # BICF2P271491 (CFA 37) is A/G with A minor
  mutate(BICF2P271491 = case_when(
    BICF2P271491 == "G G" ~ 0,
    BICF2P271491 == "A G" ~ 1,
    BICF2P271491 == "A A" ~ 2,
  )) %>% 
  mutate(ageG = case_when(
    dob >= as.Date("1/1/1985", format = "%m/%d/%Y") &
      dob < as.Date("1/1/2000", format = "%m/%d/%Y") ~ "older",
    dob >= as.Date("1/1/2000", format = "%m/%d/%Y") &
      dob < as.Date("1/1/2016", format = "%m/%d/%Y") ~ "younger"
  )) %>%  drop_na(ageG)

# Remove related dogs, prioritizing keeping controls and offspring (by removing parents)
oldDat <- filter(dat, ageG == "older" & breed == "BT") %>% 
  filter(!id %in% c("BS0700", "28285", "12933")) %>% 
  arrange(status) %>% 
  distinct(sire, dam, .keep_all = TRUE)

youngDat <- filter(dat, ageG == "younger" & breed == "BT") %>% 
  filter(!id %in% c("BPT524", "BPT090", "BPT190", "BT1301", "BS0991_31001811299544", "BPT545", "BT1332", "BT1300", "BT1291")) %>% 
  arrange(status) %>% 
  distinct(sire, dam, .keep_all = TRUE)

unrelDat <- bind_rows(oldDat, youngDat)

# Adjust dataset and filters to generate counts for each group
working <- filter(dat, breed == "BT", status == "CTL")
workingOld <- filter(working, ageG == "older")
workingYng <- filter(working, ageG == "younger")

# Ensure there are no missing data in counts
sum(is.na(working$BICF2S23230472))
sum(is.na(working$BICF2P271491))

count(working, ageG)

# BICF2S23230472 (CFA 14)
minorOldCount14 <- sum(workingOld$BICF2S23230472)
majorOldCount14 <- nrow(workingOld) * 2 - minorOldCount14

minorYngCount14 <- sum(workingYng$BICF2S23230472)
majorYngCount14 <- nrow(workingYng) * 2 - minorYngCount14

# BICF2P271491 (CFA 37)
minorOldCount37 <- sum(workingOld$BICF2P271491)
majorOldCount37 <- nrow(workingOld) * 2 - minorOldCount37

minorYngCount37 <- sum(workingYng$BICF2P271491)
majorYngCount37 <- nrow(workingYng) * 2 - minorYngCount37